@@ -33,37 +33,44 @@ def _format(
 
     if fig.layout.title.text is None:
         warnings.warn("Title is not specified!")
-    if fig.layout.xaxis.title.text is None:
-        warnings.warn("X-axis label not specified!")
-    if fig.layout.yaxis.title.text is None:
-        warnings.warn("Y-axis label not specified!")
-
-    if fig.layout.title.text is not None:
+    else:
         new_title = " ".join(fig.layout.title.text.split("_")).capitalize()
         fig.update_layout(title=new_title, title_font_color="#162b5d")
-    if fig.layout.xaxis.title.text is not None:
-        new_xlabel = " ".join(fig.layout.xaxis.title.text.split("_")).capitalize()
-        fig.update_layout(xaxis_title=new_xlabel)
-    if fig.layout.yaxis.title.text is not None:
-        new_ylabel = " ".join(fig.layout.yaxis.title.text.split("_")).capitalize()
-        fig.update_layout(yaxis_title=new_ylabel)
+
     if fig.layout.legend:
         fig.update_layout(legend_font_color="#162b5d")
 
-    if subgraph_num > 1:
+    if subgraph_num == 1:
+        if fig.layout.xaxis.title.text is None:
+            warnings.warn("X-axis label not specified!")
+        else:
+            new_xlabel = " ".join(fig.layout.xaxis.title.text.split("_")).capitalize()
+            fig.update_layout(xaxis_title=new_xlabel)
+
+        if fig.layout.yaxis.title.text is None:
+            warnings.warn("Y-axis label not specified!")
+        else:
+            new_ylabel = " ".join(fig.layout.yaxis.title.text.split("_")).capitalize()
+            fig.update_layout(yaxis_title=new_ylabel)
+
+    else:
+        if fig.layout.xaxis.title.text is None:
+            warnings.warn("X-axis label of subgraph 1 not specified!")
+        if fig.layout.yaxis.title.text is None:
+            warnings.warn("Y-axis label of subgraph 1 not specified!")
+
         for i in range(2, subgraph_num + 1):
             if fig.layout[f"xaxis{i}"].title.text is None:
                 warnings.warn(f"X-axis label of subgraph{i} label not specified!")
-            if fig.layout[f"yaxis{i}"].title.text is None:
-                warnings.warn(f"Y-axis label of subgraph{i} not specified!")
-
-            if fig.layout[f"xaxis{i}"].title.text is not None:
+            else:
                 new_xlabel = " ".join(
                     fig.layout[f"xaxis{i}"].title.text.split("_")
                 ).capitalize()
                 fig.layout[f"xaxis{i}"].title.text = new_xlabel
 
-            if fig.layout[f"yaxis{i}"].title.text is not None:
+            if fig.layout[f"yaxis{i}"].title.text is None:
+                warnings.warn(f"Y-axis label of subgraph{i} not specified!")
+            else:
                 new_ylabel = " ".join(
                     fig.layout[f"yaxis{i}"].title.text.split("_")
                 ).capitalize()
